@@ -22,8 +22,8 @@
  * Some stuff i need in a lot of places so i dropped in all together in one file.
  */
 
-#ifndef UTILS
-#define UTILS
+#ifndef GPARTED_UTILS_H
+#define GPARTED_UTILS_H
 
 #include "../include/i18n.h"
 
@@ -50,6 +50,8 @@ const Byte_Value KIBIBYTE=1024;
 const Byte_Value MEBIBYTE=(KIBIBYTE * KIBIBYTE);
 const Byte_Value GIBIBYTE=(MEBIBYTE * KIBIBYTE);
 const Byte_Value TEBIBYTE=(GIBIBYTE * KIBIBYTE);
+const Byte_Value PEBIBYTE=(TEBIBYTE * KIBIBYTE);
+const Byte_Value EXBIBYTE=(PEBIBYTE * KIBIBYTE);
 
 const Glib::ustring UUID_RANDOM = _("(New UUID - will be randomly generated)") ;
 const Glib::ustring UUID_RANDOM_NTFS_HALF = _("(Half new UUID - will be randomly generated)") ;
@@ -126,6 +128,7 @@ struct FS
 	Support read_uuid ;
 	Support write_uuid ;
 	Support create ;
+	Support create_with_label ;  //Can and how to format file system with label
 	Support grow ;
 	Support shrink ;
 	Support move ; //startpoint and endpoint
@@ -139,8 +142,8 @@ struct FS
 	
 	FS()
 	{
-		read = read_label = write_label = read_uuid = write_uuid = create = grow = shrink =
-		move = check = copy = remove = online_read = NONE ;
+		read = read_label = write_label = read_uuid = write_uuid = create = create_with_label =
+		grow = shrink = move = check = copy = remove = online_read = NONE ;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -192,6 +195,8 @@ public:
 	static int get_mounted_filesystem_usage( const Glib::ustring & mountpoint,
 	                                         Byte_Value & fs_size, Byte_Value & fs_free,
 	                                         Glib::ustring error_message ) ;
+	static Byte_Value floor_size( Byte_Value value, Byte_Value rounding_size ) ;
+	static Byte_Value ceil_size( Byte_Value value, Byte_Value rounding_size ) ;
 
 private:
 	static bool get_kernel_version( int & major_ver, int & minor_ver, int & patch_ver ) ;
@@ -199,4 +204,4 @@ private:
 
 }//GParted
 
-#endif //UTILS
+#endif /* GPARTED_UTILS_H */
