@@ -15,10 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
- 
- 
-#ifndef DEFINE_FAT16
-#define DEFINE_FAT16
+
+
+#ifndef GPARTED_FAT16_H
+#define GPARTED_FAT16_H
 
 #include "../include/FileSystem.h"
 
@@ -27,7 +27,11 @@ namespace GParted
 
 class fat16 : public FileSystem
 {
+	const enum FILESYSTEM specific_type ;
+	Glib::ustring create_cmd ;
+	Glib::ustring check_cmd ;
 public:
+	fat16( enum FILESYSTEM type ) : specific_type( type ), create_cmd( "" ), check_cmd( "" ) {} ;
 	const Glib::ustring get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) ;
 	FS get_filesystem_support() ;
 	void set_used_sectors( Partition & partition ) ;
@@ -38,9 +42,11 @@ public:
 	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
 	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 
+private:
 	static const Glib::ustring Change_UUID_Warning [] ;
+	const Glib::ustring pad_label( const Glib::ustring &label ) const ;
 };
 
 } //GParted
 
-#endif //FAT16
+#endif /* GPARTED_FAT16_H */
