@@ -33,6 +33,7 @@ FS ext2::get_filesystem_support()
 	if ( ! Glib::find_program_in_path( "mkfs." + Utils::get_filesystem_string( specific_type ) ).empty() )
 	{
 		fs .create = FS::EXTERNAL ;
+		fs .create_with_label = FS::EXTERNAL ;
 
 		if ( ! Glib::find_program_in_path( "dumpe2fs" ) .empty() )
 			fs .read = FS::EXTERNAL ;
@@ -186,14 +187,14 @@ bool ext2::resize( const Partition & partition_new, OperationDetail & operationd
 	
 	if ( ! fill_partition )
 		str_temp += " " + Utils::num_to_str( Utils::round( Utils::sector_to_unit( 
-					partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) -1 ) + "K" ; 
-		
+					partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) ) + "K" ;
+
 	return ! execute_command( str_temp, operationdetail ) ;
 }
 
 bool ext2::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	exit_status = execute_command( "e2fsck -f -y -v " + partition.get_path(), operationdetail,
+	exit_status = execute_command( "e2fsck -f -y -v -C 0 " + partition.get_path(), operationdetail,
 				       false, true );
 
 	//exitstatus 256 isn't documented, but it's returned when the 'FILE SYSTEM IS MODIFIED'
